==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PolarBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsDescriptionMetadata } from "./AssigningPolarStyleEventArgsDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescriptionMetadata } from "./AssigningPolarMarkerStyleEventArgsDescriptionMetadata";
import { MarkerSeriesDescriptionMetadata } from "./MarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
var PolarBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarBaseDescriptionMetadata, _super);
    function PolarBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarBaseDescriptionMetadata.b = function (a) {
        if (PolarBaseDescriptionMetadata.a == null) {
            PolarBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarBaseDescriptionMetadata.c(PolarBaseDescriptionMetadata.a);
        }
        if (a.j(PolarBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(PolarBaseDescriptionMetadata.a);
        AssigningPolarStyleEventArgsDescriptionMetadata.d(a);
        AssigningPolarMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    PolarBaseDescriptionMetadata.c = function (a) {
        MarkerSeriesDescriptionMetadata.c(a);
        a.item("AngleMemberPath", "String");
        a.item("RadiusMemberPath", "String");
        a.item("AngleAxisRef", "(w:AngleAxis,wf:AngleAxis)DataRef::object");
        a.item("AngleAxisRef@nameBinding", "true");
        a.item("RadiusAxisRef", "(w:RadiusAxis,wf:RadiusAxis)DataRef::object");
        a.item("RadiusAxisRef@nameBinding", "true");
        a.item("UseCartesianInterpolation", "Boolean");
        a.item("MaximumMarkers", "Number:int");
        a.item("TrendLineType", "ExportedType:string:TrendLineType");
        a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
        a.item("TrendLineBrush", "Brush");
        a.item("ActualTrendLineBrush", "Brush");
        a.item("TrendLineThickness", "Number:double");
        a.item("TrendLinePeriod", "Number:int");
        a.item("TrendLineZIndex", "Number:int");
        a.item("ClipSeriesToBounds", "Boolean");
        a.item("ActualItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
        a.item("ActualItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
        a.item("ItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("IsCustomPolarStyleAllowed", "Boolean");
        a.item("IsCustomPolarMarkerStyleAllowed", "Boolean");
        a.item("RadiusMemberAsLegendLabel", "String");
        a.item("AngleMemberAsLegendLabel", "String");
        a.item("RadiusMemberAsLegendUnit", "String");
        a.item("AngleMemberAsLegendUnit", "String");
        a.item("AssigningPolarStyleRef", "EventRef::assigningPolarStyle");
        a.item("AssigningPolarMarkerStyleRef", "EventRef::assigningPolarMarkerStyle");
    };
    PolarBaseDescriptionMetadata.d = function (a) {
        PolarBaseDescriptionMetadata.b(a);
        a.z("PolarBase", PolarBaseDescriptionMetadata.a);
    };
    PolarBaseDescriptionMetadata.$t = markType(PolarBaseDescriptionMetadata, 'PolarBaseDescriptionMetadata');
    PolarBaseDescriptionMetadata.a = null;
    return PolarBaseDescriptionMetadata;
}(Base));
export { PolarBaseDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/PolarBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningPolarStyleEventArgsDescriptionMetadata } from "./AssigningPolarStyleEventArgsDescriptionMetadata";
import { AssigningPolarMarkerStyleEventArgsDescriptionMetadata } from "./AssigningPolarMarkerStyleEventArgsDescriptionMetadata";
import { MarkerSeriesDescriptionMetadata } from "./MarkerSeriesDescriptionMetadata";
/**
 * @hidden
 */
var PolarBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarBaseDescriptionMetadata, _super);
    function PolarBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarBaseDescriptionMetadata.b = function (a) {
        if (PolarBaseDescriptionMetadata.a == null) {
            PolarBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarBaseDescriptionMetadata.c(PolarBaseDescriptionMetadata.a);
        }
        if (a.k(PolarBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(PolarBaseDescriptionMetadata.a);
        AssigningPolarStyleEventArgsDescriptionMetadata.d(a);
        AssigningPolarMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    PolarBaseDescriptionMetadata.c = function (a) {
        MarkerSeriesDescriptionMetadata.c(a);
        a.item("AngleMemberPath", "String");
        a.item("RadiusMemberPath", "String");
        a.item("AngleAxisRef", "(w:AngleAxis,wf:AngleAxis)DataRef::object");
        a.item("AngleAxisRef@nameBinding", "true");
        a.item("RadiusAxisRef", "(w:RadiusAxis,wf:RadiusAxis)DataRef::object");
        a.item("RadiusAxisRef@nameBinding", "true");
        a.item("UseCartesianInterpolation", "Boolean");
        a.item("MaximumMarkers", "Number:int");
        a.item("TrendLineType", "ExportedType:string:TrendLineType");
        a.item("TrendLineType@names", "None;LinearFit;QuadraticFit;CubicFit;QuarticFit;QuinticFit;LogarithmicFit;ExponentialFit;PowerLawFit;SimpleAverage;ExponentialAverage;ModifiedAverage;CumulativeAverage;WeightedAverage");
        a.item("TrendLineBrush", "Brush");
        a.item("ActualTrendLineBrush", "Brush");
        a.item("TrendLineThickness", "Number:double");
        a.item("TrendLinePeriod", "Number:int");
        a.item("TrendLineZIndex", "Number:int");
        a.item("ClipSeriesToBounds", "Boolean");
        a.item("ActualItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
        a.item("ActualItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
        a.item("ItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("IsCustomPolarStyleAllowed", "Boolean");
        a.item("IsCustomPolarMarkerStyleAllowed", "Boolean");
        a.item("RadiusMemberAsLegendLabel", "String");
        a.item("AngleMemberAsLegendLabel", "String");
        a.item("RadiusMemberAsLegendUnit", "String");
        a.item("AngleMemberAsLegendUnit", "String");
        a.item("AssigningPolarStyleRef", "EventRef::assigningPolarStyle");
        a.item("AssigningPolarMarkerStyleRef", "EventRef::assigningPolarMarkerStyle");
    };
    PolarBaseDescriptionMetadata.d = function (a) {
        PolarBaseDescriptionMetadata.b(a);
        a.ab("PolarBase", PolarBaseDescriptionMetadata.a);
    };
    PolarBaseDescriptionMetadata.$t = markType(PolarBaseDescriptionMetadata, 'PolarBaseDescriptionMetadata');
    PolarBaseDescriptionMetadata.a = null;
    return PolarBaseDescriptionMetadata;
}(Base));
export { PolarBaseDescriptionMetadata };
